;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "otpp" "20250909.2023"
  "One tab per project, with unique names."
  '((emacs  "28.1")
    (compat "29.1"))
  :url "https://github.com/abougouffa/one-tab-per-project"
  :commit "fb8e72b924013443ba810ad5347d6ca39f005158"
  :revdesc "fb8e72b92401"
  :keywords '("convenience")
  :authors '(("Abdelhak Bougouffa (rot13" . "\"nobhtbhssn@srqbencebwrpg.bet\")"))
  :maintainers '(("Abdelhak Bougouffa (rot13" . "\"nobhtbhssn@srqbencebwrpg.bet\")")))
